@@ -38,7 +38,14 @@ Revision History:
 MODULE_DESCRIPTION(CPQCI_DESCRIPTION);
 #endif
 #if LINUX_VERSION_CODE >= 0x020600
+
 MODULE_LICENSE("Proprietary");
+
+static const struct pci_device_id __pci_dev[] = { 
+	{ PCI_DEVICE(CPQCI_VEND_ID, CPQCI_DEV_ID), },
+	{ 0 }
+};
+MODULE_DEVICE_TABLE(pci, __pci_dev);
 #endif
 
 #ifdef  DEBUG 
@@ -452,6 +459,12 @@ void cleanup_module_helper(int irq_status, int irq, int register_status, struct
 	//  If the adapter device object was created, then we have other 
 	//  resources to wack.
 	if (adapterExtension) {
+#if LINUX_VERSION_CODE >= 0x020600
+		if (adapterExtension->pdev) {
+//			pci_dev_put(adapterExtension->pdev);  Need to debug later
+		}
+#endif
+
 		DBG("(adapter)kfree(%p)\n", adapterExtension);
 		kfree(adapterExtension);
 	}
@@ -552,8 +565,7 @@ Return Value:
 
 
 	DBG("Scanning PCI for %08x\n", CPQCI_SIGNATURE);
-	pd = pci_find_device(CPQCI_SIGNATURE & 0xFFFF,
-			    CPQCI_SIGNATURE >> 16, NULL);
+	pd = pci_find_device(CPQCI_VEND_ID, CPQCI_DEV_ID, NULL);
 	if (!pd) {
 		DBG("CpqCiDrv!init_module: can't find %08x\n",
 			    CPQCI_SIGNATURE);
@@ -564,6 +576,19 @@ Return Value:
 	pci_read_config_dword(pd, CPQCI_REG_MMIOREGBAR, (u32 *) & mmioreg);
 	mmioregsize = 0x1000;
 
+	//*******************************************************************
+	// We need to use pci_enable_device to make sure interrupts are
+	// properly routed.  SLES 9 / SLES 10 do something a little different
+	// with the routing of ACPI GSI interrupts when this function is called.
+	//*******************************************************************
+
+	error = pci_enable_device(pd);
+	if (error) {
+		printk(KERN_WARNING "Not able to enable PCI device:  %d\n", error);
+		status = ENODEV;
+		goto bad_exit;
+	}
+ 
 	//*******************************************************************
 	//  Create a device specific adapter object.
 	//*******************************************************************
@@ -599,6 +624,7 @@ Return Value:
 	adapterExtension->Adapter = adapter;
 	adapterExtension->ConnectionList = NULL;
 	adapterExtension->irq = pd->irq;
+	adapterExtension->pdev = pd;
 
 	//*******************************************************************
 	//*******************************************************************
@@ -795,6 +821,12 @@ int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg,
 	struct _CPQCIDRVOSMEMHANDLE mh64;
 	CPQCIDRVHANDLEPARMS32 *ub32 = (CPQCIDRVHANDLEPARMS*) arg;
 	CPQCIDRVHANDLEPARMS ub64;
+
+#if LINUX_VERSION_CODE >= 0x020610
+	CPQCIDRVHANDLEPARMS  __user *pub = NULL;
+	struct _CPQCIDRVOSMEMHANDLE  __user *pmh = NULL;
+#endif
+
 	DBG("Entered cpqci_ioctl32_handler cmd: %p\n", cmd) ;
 
 	switch (cmd) {
@@ -806,7 +838,32 @@ int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg,
 		err |= get_user(mh64.Attributes, &mh32->Attributes);
 		if (err) return -EFAULT;
 #if LINUX_VERSION_CODE >= 0x020610
-		err = do_cpqci_ioctl(file, cmd, (unsigned long)&mh64);
+
+		pmh = compat_alloc_user_space(sizeof(mh64));
+		if (!pmh) {
+			DBG("cpqci_ioctl32_handler cmd: No compat_alloc_user_space: pmh\n") ;
+			return -EFAULT;
+		}
+
+
+		err |= copy_to_user(pmh, &mh64, sizeof(mh64));
+		if (err) {
+			DBG("CPQCI_CREATE_CHANNEL:  COMPAT COPY FAILED\n") ;
+			return -EFAULT;
+		}
+		err = do_cpqci_ioctl(file, cmd, (unsigned long)pmh);
+
+		if (err) {
+			DBG("do_cpqci_ioctl error:  %d\n", err) ;
+			return -EFAULT;
+		}
+
+		err |= copy_from_user(&mh64, pmh, sizeof(mh64));
+
+		if (err) {
+			DBG("copy_from_user error:  %d\n", err) ;
+			return -EFAULT;
+		}
 #else
 		old_fs = get_fs();
 		set_fs(KERNEL_DS);
@@ -834,7 +891,32 @@ int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg,
 		err |= get_user(ub64.Oshandle, &ub32->Oshandle);
 		if (err) return -EFAULT;
 #if LINUX_VERSION_CODE >= 0x020610
-		err = do_cpqci_ioctl(file, cmd, (unsigned long)&ub64);
+
+		pub = compat_alloc_user_space(sizeof(ub64));
+		if (!pub) {
+			DBG("cpqci_ioctl32_handler cmd: No compat_alloc_user_space: pub\n") ;
+			return -EFAULT;
+		}
+
+
+		err |= copy_to_user(pub, &ub64, sizeof(ub64));
+		if (err) {
+			DBG("CPQCI_CREATE_CHANNEL:  COMPAT COPY FAILED\n") ;
+			return -EFAULT;
+		}
+		err = do_cpqci_ioctl(file, cmd, (unsigned long)pub);
+
+		if (err) {
+			DBG("do_cpqci_ioctl error:  %d\n", err) ;
+			return -EFAULT;
+		}
+
+		err |= copy_from_user(&ub64, pub, sizeof(ub64));
+
+		if (err) {
+			DBG("copy_from_user error:  %d\n", err) ;
+			return -EFAULT;
+		}
 #else
 		old_fs = get_fs();
 		set_fs(KERNEL_DS);
@@ -1003,6 +1085,7 @@ Return Value:
 		if (copy_from_user(ub, (CPQCIDRVHANDLEPARMS *) arg,
 				   sizeof(CPQCIDRVHANDLEPARMS))) {
 			status =  -EFAULT;
+			DBG("Copy from user failed:  %p\n", c);
 			goto bad_ioctl_exit_0;
 		}
 		
@@ -1340,7 +1423,10 @@ irqreturn_t cpqci_intr(int irq, void *dev_id, struct pt_regs *regs)
 #if LINUX_VERSION_CODE < 0x020600
 	if (adapterExtension != CpqCi) return;
 #else
-	if (adapterExtension != CpqCi) return IRQ_NONE;
+	if (adapterExtension != CpqCi) {
+		printk ("Not Accepting IRQ - IRQ_NONE\n");
+		return IRQ_NONE;
+	}
 #endif
 
 	DBG("Interrupt\n");
