@@ -33,15 +33,15 @@
 #define DBG( fmt, args...) 
 #endif
 
-#if (LINUX_VERSION_CODE >= 0x020300) && !(defined(SLES7))
+//#if (LINUX_VERSION_CODE >= 0x020300) && !(defined(SLES7))
 #define PRINTF(fmt, args...)\
 buflen+=CpqCiSNPrintf(buffer+buflen, bufsize-buflen, fmt, ##args);
-#else
-#define PRINTF(fmt, args...)\
-if (bufsize-buflen > 256) {\
-	buflen+=CpqCiSPrintf(buffer+buflen, fmt, ##args);\
-}
-#endif
+//#else
+//#define PRINTF(fmt, args...)\
+//if (bufsize-buflen > 256) {\
+//	buflen+=CpqCiSPrintf(buffer+buflen, fmt, ##args);\
+//}
+//#endif
 
 //#endif /* Linux */
 
