@@ -165,6 +165,28 @@ typedef struct _CRIDDATA {
 #define CRID_REGISTER_MEMORY_MAP2	0x8	/* Memory mapped Phase 2 */
 #define CRID_REGISTER_PROC		0x10	/* Proc tables are registered */
 
+//*************************************************************************
+//  Defines for PCI information 
+//*************************************************************************
+#define PCI_VEND_ID		 			0x8086
+#define PCI_DEV_ID 					0x1960
+#define PCI_VEND_ID_2		 			0x0E11
+#define PCI_DEV_ID_2					0x005A
+// FPGA on RILOE II; needed for firmware > 1.10
+#define PCI_VEND_ID_3					0x0E11
+#define PCI_DEV_ID_3					0x00B1
+//#define PCI_BRDID                                     "0x80861960"
+//#define PCI_SBRDID                                    "0xE11C000"   
+/* DO NOT PAD 'E' with a preceding zero. Resmgr stores it without the preceding zero.*/
+//#define BRDID_SZ                                      11
+//#define SBRDID_SZ                                     13
+#define SUB_SYS_VEND_ID					0x0E11
+#define SUB_DEV_ID					0xC000
+#define SUB_SYS_VEND_ID_2				0x0E11
+#define SUB_DEV_ID_2					0x00B2
+#define SUB_SYS_VEND_ID_3				0x0E11
+#define SUB_DEV_ID_3					0x00B3
+#define PCI_ENBL_INTR					0xFFFFFFFB
 
 #ifndef _SKIP_PUB_PROTO
 //*************************************************************************
