@@ -34,7 +34,16 @@
 #endif
 
 #if LINUX_VERSION_CODE >= 0x020600
+
 MODULE_LICENSE("Proprietary");
+
+static const struct pci_device_id __pci_dev[] = {
+	{ PCI_DEVICE(PCI_VEND_ID, PCI_DEV_ID), },
+	{ PCI_DEVICE(PCI_VEND_ID_2, PCI_DEV_ID_2), },
+	{ PCI_DEVICE(PCI_VEND_ID_3, PCI_DEV_ID_3), },
+	{ 0 }
+};
+MODULE_DEVICE_TABLE(pci, __pci_dev);
 #endif
 
 #ifdef CPQRID_DESCRIPTION
