@@ -152,16 +152,16 @@ sub Intro {
    my $input ;
 
    print "-------------------------------------------------------------------------------
-   Welcome to the Setup Wizard for the HP System Management HomePage 2.1.2
+   Welcome to the Setup Wizard for the HP System Management HomePage 2.1.6
 
-   The Setup Wizard will install the HP System Management HomePage 2.1.2 on
+   The Setup Wizard will install the HP System Management HomePage 2.1.6 on
    your computer.
 
    On the following screens, you will configure security and access parameters
    for the HP System Management HomePage and related HP web-based management
    tools (e.g. Insight Management Agents, Version Control Agents, Diagnostics).
 
-   HP System Management HomePage 2.1.2
+   HP System Management HomePage 2.1.6
    Hewlett-Packard Company
    www.hp.com\n\n" ;
 
@@ -683,17 +683,17 @@ sub getXENames {
 
    print "
    Setup the System Management HomePage to accept Secure Task Execution
-   and Single Login requests from Insight Manager 7.\n\n" ; 
+   and Single Login requests from Systems Insight Manager.\n\n" ; 
 
    do {
 
    &printXENames (@XENames) ;
 
    print "
-   Modify Insight Manager 7 Server List
-   ------------------------------------
-   1 - Add    Insight Manager 7 Server
-   2 - Delete Insight Manager 7 Server
+   Modify Systems Insight Manager Server List
+   ------------------------------------------
+   1 - Add    Systems Insight Manager
+   2 - Delete Systems Insight Manager
    
    p - previous
    n - next\n\n" ;
@@ -713,7 +713,7 @@ sub getXENames {
    if ($key == '1') {
       $error = "" ;
 
-      print "   Please enter the Insight Manager 7 Server to add: " ;
+      print "   Please enter the Systems Insight Manager Server to add: " ;
       $input = <STDIN> ;
       chomp ($input) ;
 
@@ -738,7 +738,7 @@ sub getXENames {
 
       $count = scalar (@XENames) ;
 
-      print "\n   Enter the number of the Insight Manager 7 Server to delete,\n" ;
+      print "\n   Enter the number of the Systems Insight Manager Server to delete,\n" ;
       print "   or ENTER when you are finished: " ;
 
       $input = <STDIN> ;
